@@ -39,12 +39,11 @@ IG_TERMS = TERMS["instagram"]
 
 class MainETL:
     """
-    :Date: 2022-11-03
-    :Version: 1.3
+    :Date: 2022-11-10
+    :Version: 1.4
     :Author: Joan Felipe Mendoza - Whale & Jaguar Consultants S.A.S.
-    :Description: PIPELINE SOBRE AWS
+    :Description: PIPELINE PRINCIPAL
     """
-
     def __init__(self) -> None:
         try:
             nltk.download('stopwords')
@@ -116,35 +115,47 @@ class MainETL:
                 contacts: lista de usuarios a contactar (:type: list[dict])
         """
         # Descargar datos desde Twitter y almacenar en DB
+        start = datetime.now()
         contacts = {}
         data = pd.DataFrame()
-        if len(tweets_data):
+        lng = len(tweets_data)
+        print("***")
+        if lng:
             # Derivar
-            data = self.derive_tw(tweets_data)
+            tweets_data = pd.DataFrame(tweets_data).drop_duplicates(subset=["tweet_id"]).to_dict("records")
+            tweets_data = self.multiprocess(target_method=self.transform_data, data=tweets_data)
+            tweets_data = pd.DataFrame(tweets_data)
+            data = tweets_data[tweets_data["country_iso2"].isin(COUNTRIES)].to_dict("records")
+            data = self.derive_tw(data)
             # Calcular lista de usuarios a contactar
-            true_cases = data[
-                (data[TARGET] == 1) & (data["gender"].isin(["M", "F"])) & (data["country_iso2"].isin(COUNTRIES))
-                & (data["verified"] == 0)
-                ]
-            contacts = true_cases[["screen_name", "twitter_id", "user_name"]].drop_duplicates().to_dict("records")
+            if data.shape[0]:
+                true_cases = data[(data[TARGET] == 1) & (data["gender"].isin(["M", "F"])) & (data["verified"] == 0)]
+                contacts = true_cases[["screen_name", "twitter_id", "user_name"]].drop_duplicates().to_dict("records")
+            data_0 = tweets_data[~tweets_data["country_iso2"].isin(COUNTRIES)]
+            data_0[TARGET] = [-1] * len(data_0)  # Inicializar como No predecido
+            data = pd.concat([data, data_0], axis=0).reset_index(drop=True)
+        end = datetime.now()
+        print(f"**Total time** {end - start}\n"
+              f"**Records** {lng}\n"
+              f"**Avg time per record** {(end - start) / lng if lng else 0}\n***\n")
         return data, contacts
 
     def derive_tw(self, tweets_data, model_type="bert"):
-        # Quitar duplicados
-        data = pd.DataFrame(tweets_data).drop_duplicates(subset=["tweet_id"]).to_dict('records')
-        data_from_tw = self.multiprocess(target_method=self.transform_data, data=data)
-        if data_from_tw:
-            df = pd.DataFrame(data_from_tw)
+        if len(tweets_data):
+            df = pd.DataFrame(tweets_data)
             # Clasificar conversaciones por texto
+            start = datetime.now()
             if model_type == "bert":
                 df["target_text"] = ClassifyText(model_type=model_type).predict(df["text"], clean_mode=None)
             else:
                 df["target_text"] = ClassifyText(model_type=model_type).predict(df["clean_text"], clean_mode=None)
-            df["sttm_group"] = ClassifySTTM().predict(list(df["text"]))
+            print(f"*Moment Clf total time* {datetime.now() - start}")
+            start = datetime.now()
             obj_list, top_list, color_list, img_list, target_list = [], [], [], [], []
+            l = 0
             for _, row in df.iterrows():
                 # Clasificar conversaciones por imágenes (sólo las que no dieron positivas por texto)
-                obj_img, top_labels, color_img, img_url, target_img = {}, {}, {}, None, 0
+                obj_img, top_labels, color_img, img_url, target_img = {}, {}, {}, None, -1
                 urls = row["media_url_https"][:2] if row["media_url_https"] else []
                 if urls:
                     img_url = urls[0]
@@ -154,6 +165,7 @@ class MainETL:
                         color_img = tw_img.colors
                         target_img, obj_img, top_labels = tw_img.predict()
                         img_url = url
+                        l += 1
                         if target_img:
                             break
                 obj_list.append(obj_img)
@@ -167,6 +179,18 @@ class MainETL:
             df["img_url"] = img_list
             df["target_img"] = target_list
             df[TARGET] = df[["target_img", "target_text"]].values.max(axis=1)
+            end = datetime.now()
+            print(f"*Image Clf total time* {end - start}\n"
+                  f"*Images* {l}\n"
+                  f"*Avg time per image* {(end - start) / l if l else 0}")
+            start = datetime.now()
+            df["sttm_group"] = None
+            df_1 = df[df[TARGET] == 1]
+            if df_1.shape[0]:
+                df_0 = df[df[TARGET] != 1]
+                df_1["sttm_group"] = ClassifySTTM().predict(list(df_1["text"]))
+                df = pd.concat([df_1, df_0], axis=0).reset_index(drop=True)
+            print(f"*STTM group total time* {datetime.now() - start}")
         else:
             df = pd.DataFrame()
         return df
@@ -194,28 +218,29 @@ class MainETL:
         print(f"DATA Size :: {len(data)}")
         data_from_tw = []
         for json_data in data:
-            date = str(json_data["created_at"])[:10]
-            screen_name, full_name, description = None, None, None
+            text = str(json_data["text"])
+            loc_fields = {"place": True, "user_location": True, "text": True}
+            locations, city, country = self.location_from_text(json_data, loc_fields)
+            brands = self.terms_detection(text, BRANDS["twitter"])
+            if len(brands) > 0 and country is None:
+                country = "CO"
+            screen_name, full_name, description, gender = None, None, None, None
+            clean_text, keywords, top_keyword = None, [], None
             if "screen_name" in json_data:
                 screen_name = json_data["screen_name"]
             if "user_name" in json_data:
                 full_name = json_data["user_name"]
             if "user_description" in json_data:
                 description = json_data["user_description"]
-            text = str(json_data["text"])
-            clean_text = NlpUtils().clean_text(text)
-            loc_fields = {"text": True, "place": True, "user_location": True}
-            locations, city, country = self.location_from_text(json_data, loc_fields)
-            brands = self.terms_detection(text, BRANDS["twitter"])
-            keywords = self.terms_detection(text, TERMS["twitter"])
-            kwrds = brands + keywords
-            top_keyword = kwrds[0] if kwrds else None
-            if len(brands) > 0 and country is None:
-                country = "CO"
-            gender = GenderByText(screen_name, full_name, description, text).predict()
+            if country in COUNTRIES:
+                clean_text = NlpUtils().clean_text(text)
+                keywords = self.terms_detection(text, TERMS["twitter"])
+                kwrds = brands + keywords
+                top_keyword = kwrds[0] if kwrds else None
+                gender = GenderByText(screen_name, full_name, description, text).predict()
             data = {
                 **json_data,
-                "date": date,
+                "date": str(json_data["created_at"])[:10],
                 "clean_text": clean_text,
                 "locations": locations,
                 "city": city,
