@@ -32,14 +32,6 @@ for lng in LANGUAGES:
         str(x) for x in COUNTRIES_DF[f"denonym_{lng}"] if x not in [None, np.nan]
     ]
 
-SYNOM_PLACES = [
-    ("u.s.a.", "united states"),
-    ("u.s.a", "united states"),
-    ("usa", "united states"),
-    ("eua", "estados unidos"),
-    ("ee.uu.", "estados unidos"),
-]
-
 ES_CHAR_MAP = [
     ("ñ", "-*_n_?|"),
     ("Ñ", "-*_N_?|"),
@@ -71,8 +63,8 @@ ST = 90  # Umbral de similaridad (Levenshtein)
 
 class NlpUtils:
     """
-    :Date: 2022-10-17
-    :Version: 0.6
+    :Date: 2022-10-28
+    :Version: 0.6.1
     :Author: Joan Felipe Mendoza - Whale & Jaguar Consultants S.A.S.
     :Description: FUNCIONES AUXILIARES
     """
@@ -323,8 +315,8 @@ class CalcUtils:
 
 class Location:
     """
-    :Date: 2022-03-15
-    :Version: 0.2
+    :Date: 2022-10-27
+    :Version: 0.2.1
     :Author: Joan Felipe Mendoza - Whale & Jaguar Consultants S.A.S.
     :Description: EXTRAER UBICACIÓN DENTRO DE UN TEXTO
     """
@@ -409,19 +401,7 @@ class Location:
             matches = []
             for rex in rex_list:
                 matches += re.findall(re.compile(rex), doc)
-            # Reemplazar valores de países que causan sinonimia
-            places_candidates = []
-            for cc in matches:
-                cname = str(cc)
-                for sc in SYNOM_PLACES:
-                    if cc == sc[0]:
-                        cname = sc[1]
-                        break
-                places_candidates.append(cname)
-            final_places = list(
-                set(places_candidates)
-            )  # Obtener el lugar más frecuente
-            return final_places  # Devolver lugar
+            return list(set(matches))  # Devolver lugar
         except Exception:
             return []
 
@@ -466,7 +446,7 @@ class Location:
         :param country_iso3: nombre del país en ISO3
         :return: lista de ciudades (:type: list)
         """
-        if country_iso3 not in [""]:
+        if country_iso3 != "":
             df = CITIES_DF[CITIES_DF["countrycode_iso3"] == country_iso3]
             output = list(df["cityname"].values)
         else:
@@ -480,7 +460,7 @@ class Location:
         :param city_name: nombre de la ciudad
         :return: lista de países en ISO3 (:type: list)
         """
-        if city_name not in [""]:
+        if city_name != "":
             df = CITIES_DF[CITIES_DF["cityname"] == city_name]
             output = list(set(df["countrycode_iso3"].values))
         else:
@@ -490,8 +470,8 @@ class Location:
 
 class GenderByText:
     """
-    :Date: 2022-09-09
-    :Version: 0.1.2.1
+    :Date: 2022-10-27
+    :Version: 0.2
     :Author: Joan Felipe Mendoza - Whale & Jaguar Consultants S.A.S.
     :Description: PREDECIR GÉNERO
     """
@@ -532,8 +512,8 @@ class GenderByText:
         :param sim_th: umbral de similaridad (:type: int)
         :return: género -F o M- (:type: str)
         """
-        words = [word for word in NlpUtils.remove_punctuation(text.lower()).split() if len(word) > 2]
-        words = [word for word in words if word not in stopwords.words(lang)]
+        words = [word for word in NlpUtils.remove_punctuation(text.lower()).split()
+                 if len(word) > 2 and word not in stopwords.words(lang)]
         m_matches, f_matches = [], []
         for word in words:
             f_matches += [x for x in F_LIST if x in word]
@@ -562,8 +542,8 @@ class GenderByText:
         :return: género -F o M- (:type: str)
         """
         try:
-            m_exp = r'\b(he|his|him|man|hombre|chico|boy|guy|pibe|chavo)\b'
-            f_exp = r'\b(she|her|ella|mujer|chica|girl|chava|mina)\b'
+            m_exp = r"\b(he|his|him|man|hombre|chico|boy|guy|pibe|chavo)\b"
+            f_exp = r"\b(she|her|ella|mujer|chica|girl|chava|mina)\b"
             f_score = len(re.findall(re.compile(f_exp), self.description))
             m_score = len(re.findall(re.compile(m_exp), self.description))
             if f_score > m_score:
@@ -590,12 +570,11 @@ class GenderByText:
             sentences, se_sentences = [], []
             for tweet in text.split(sep):
                 sentences += sent_tokenize(tweet)
-            sentences = [unicodedata.normalize("NFKD", x.lower()).encode("ascii", "ignore").decode("ascii")
-                         for x in sentences]
             for sent in sentences:
+                doc = unicodedata.normalize("NFKD", sent.lower()).encode("ascii", "ignore").decode("ascii")
                 for rex in SE_REX:
-                    if len(re.findall(re.compile(rex), sent)) > 0:
-                        se_sentences.append(sent)
+                    if len(re.findall(re.compile(rex), doc)) > 0:
+                        se_sentences.append(doc)
             return self.gender_by_pos_es(re.sub(r'\.+', '.', '. '.join(se_sentences)))
         except Exception:
             return ""
